##  Permissions
By default, only admins have full permissions for architecture decisions. The following table lists permissions for standard user roles.
User Role | Default Permissions for Architecture Decisions
---|---
Viewer | View
Member | View, create, and update
Admin | View, create, update, and delete


Admins can customize permissions for non-admin roles. To do this, follow these steps:
  1. Go to the User Roles and Permissions section of the admin area.
  2. Select a non-admin user role, then navigate to the Permissions tab.
  3. In the Architecture Decisions section, adjust the permissions as needed, then save the changes.


![Adjusting Permissions for Architecture Decisions for a Non-Admin User Role](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274bce377a4410148c2586c46e95a641_LowRes.png)
Adjusting Permissions for Architecture Decisions for a Non-Admin User Role
For more information on managing permissions, see [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
